@@ -313,9 +313,7 @@ OrgFreedesktopDBusMockInterface & DBusMock::mockInterface(const QString &name,
 		const QString &path, const QString &interface,
 		QDBusConnection::BusType busType) {
 	Q_UNUSED(interface);
-	QString id(name);
-	id.append(':');
-	id.append(path);
+	QString id(QStringLiteral("%1:%2:%3").arg(int(busType)).arg(name).arg(path));
 	auto it(d->m_mockInterfaces.find(id));
 	if (it == d->m_mockInterfaces.end()) {
 		switch (busType) {
