@@ -77,9 +77,15 @@ static void transform(QVariantMap &map);
 
 static QVariant transform(const QDBusArgument & value) {
 	switch (value.currentType()) {
+	case QDBusArgument::BasicType: {
+		return value.asVariant();
+	}
 	case QDBusArgument::ArrayType: {
 		value.beginArray();
-		QVariantList list = transform(value).toList();
+		QVariantList list;
+		while (!value.atEnd()) {
+			list << transform(value);
+		}
 		value.endArray();
 		return list;
 	}
